summaryrefslogtreecommitdiff
path: root/src/webob
diff options
context:
space:
mode:
authorKirill Kuzminykh <cykooz@gmail.com>2018-03-08 13:27:52 +0300
committerKirill Kuzminykh <cykooz@gmail.com>2018-03-08 13:27:52 +0300
commit54554674aa10b545f9560209faa84ca4bdc0a4c8 (patch)
tree36234b631e2cf639f8ee7cae194bfbecf77ce4a2 /src/webob
parentc5ab02c698fe0b6a9f8f87cfafb066157db20d7f (diff)
downloadwebob-54554674aa10b545f9560209faa84ca4bdc0a4c8.tar.gz
``request.POST`` now supports DELETE requests with the appropriate Content-Type (#351).
Diffstat (limited to 'src/webob')
-rw-r--r--src/webob/request.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/webob/request.py b/src/webob/request.py
index 46c2de7..6d1a459 100644
--- a/src/webob/request.py
+++ b/src/webob/request.py
@@ -752,11 +752,11 @@ class BaseRequest(object):
Return a MultiDict containing all the variables from a form
request. Returns an empty dict-like object for non-form requests.
- Form requests are typically POST requests, however PUT & PATCH requests
- with an appropriate Content-Type are also supported.
+ Form requests are typically POST requests, however PUT, PATCH & DELETE
+ requests with an appropriate Content-Type are also supported.
"""
env = self.environ
- if self.method not in ('POST', 'PUT', 'PATCH'):
+ if self.method not in ('POST', 'PUT', 'PATCH', 'DELETE'):
return NoVars('Not a form request')
if 'webob._parsed_post_vars' in env:
vars, body_file = env['webob._parsed_post_vars']